==> qtjambi-qt3drender-5.15.9-sources.jar: io/qt/qt3d/render/QFilterKey.java <==
package io.qt.qt3d.render;


/**
 * <p>Storage for filter keys and their values</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qfilterkey.html">Qt3DRender::QFilterKey</a></p>
 */
public class QFilterKey extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFilterKey.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qfilterkey.html#name-prop">Qt3DRender::QFilterKey::nameChanged(QString)</a></p>
     */
    @io.qt.QtPropertyNotify(name="name")
    public final Signal1<java.lang.String> nameChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qfilterkey.html#value-prop">Qt3DRender::QFilterKey::valueChanged(QVariant)</a></p>
     */
    @io.qt.QtPropertyNotify(name="value")
    public final Signal1<java.lang.Object> valueChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QFilterKey(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QFilterKey() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QFilterKey(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFilterKey instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qfilterkey.html#name-prop">Qt3DRender::QFilterKey::name()const</a></p>
     */
    @io.qt.QtPropertyReader(name="name")
    @io.qt.QtUninvokable
    public final java.lang.String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qfilterkey.html#name-prop">Qt3DRender::QFilterKey::setName(QString)</a></p>
     */
    @io.qt.QtPropertyWriter(name="name")
    public final void setName(java.lang.String customType){
        setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), customType);
    }
    
    private native void setName_native_cref_QString(long __this__nativeId, java.lang.String customType);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qfilterkey.html#value-prop">Qt3DRender::QFilterKey::setValue(QVariant)</a></p>
     */
    @io.qt.QtPropertyWriter(name="value")
    public final void setValue(java.lang.Object value){
        setValue_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setValue_native_cref_QVariant(long __this__nativeId, java.lang.Object value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qfilterkey.html#value-prop">Qt3DRender::QFilterKey::value()const</a></p>
     */
    @io.qt.QtPropertyReader(name="value")
    @io.qt.QtUninvokable
    public final java.lang.Object value(){
        return value_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object value_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QFilterKey(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QFilterKey(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QFilterKey instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QFilterKey.java <==
package io.qt.qt3d.render;


/**
 * <p>Storage for filter keys and their values</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qfilterkey.html">Qt3DRender::QFilterKey</a></p>
 */
public class QFilterKey extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFilterKey.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qfilterkey.html#name-prop">Qt3DRender::QFilterKey::nameChanged(QString)</a></p>
     */
    @io.qt.QtPropertyNotify(name="name")
    public final Signal1<java.lang.String> nameChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qfilterkey.html#value-prop">Qt3DRender::QFilterKey::valueChanged(QVariant)</a></p>
     */
    @io.qt.QtPropertyNotify(name="value")
    public final Signal1<java.lang.Object> valueChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QFilterKey(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QFilterKey() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QFilterKey(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFilterKey instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qfilterkey.html#name-prop">Qt3DRender::QFilterKey::name()const</a></p>
     */
    @io.qt.QtPropertyReader(name="name")
    @io.qt.QtUninvokable
    public final java.lang.String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qfilterkey.html#name-prop">Qt3DRender::QFilterKey::setName(QString)</a></p>
     */
    @io.qt.QtPropertyWriter(name="name")
    public final void setName(java.lang.String customType){
        setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), customType);
    }
    
    private native void setName_native_cref_QString(long __this__nativeId, java.lang.String customType);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qfilterkey.html#value-prop">Qt3DRender::QFilterKey::setValue(QVariant)</a></p>
     */
    @io.qt.QtPropertyWriter(name="value")
    public final void setValue(java.lang.Object value){
        setValue_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setValue_native_cref_QVariant(long __this__nativeId, java.lang.Object value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qfilterkey.html#value-prop">Qt3DRender::QFilterKey::value()const</a></p>
     */
    @io.qt.QtPropertyReader(name="value")
    @io.qt.QtUninvokable
    public final java.lang.Object value(){
        return value_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object value_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QFilterKey(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QFilterKey(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QFilterKey instance, QDeclarativeConstructor constructor);
    
}
